TestInstance

Struct TestInstance 

pub struct TestInstance {
    pub instance: DockerTest,
}
A single test instance made up of several Compositions which are brought up for executing tests.

Use the run method to run the containers and perform the test logic.

Fields

instance: DockerTest

Implementations

Source

impl TestInstance

pub fn new(servers: Vec<Composition>) -> TestInstance

Returns a new TestInstance configured with the given Compositions.

pub fn add(&mut self, comp: Composition)

Adds a Composition to this TestInstance.

pub fn run<T, F>(self, fun: T)
where T: FnOnce(DockerOperations) -> F + Send + 'static, F: Future<Output = ()> + Send + 'static,

Runs all containers from the associated Compositions, verifying they are running according to their startup conditions, and then calls the passed closure with runtime details.

This is the main method for running the TestInstance. All test logic should be encompassed within the passed closure. Creating and destroying containers happens upon entering/leaving the closure.