Server

Trait Server 

pub trait Server {
    type Config;

    // Required method
    fn new(ops: &DockerOperations, config: &Self::Config) -> Self;
}
An instance of a server that is created after it’s associated Composition has been brought up.

This trait is the main vehicle for tests to interact with the running container. It should encompass all logic necessary for tests to successfully interact with it.

Required Associated Types

Required Methods

fn new(ops: &DockerOperations, config: &Self::Config) -> Self

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors