ServerConfig

Trait ServerConfig 

pub trait ServerConfig {
    // Required methods
    fn to_comp(&self) -> Composition;
    fn to_instance(&self) -> TestInstance;
}
A server configuration which can be converted into a Composition to be ran as a container.

Types implementing this trait should collect all required configuration data and use ServerConfig::to_comp to convert it into a Composition to be run by a TestInstance. The associated Server for this configuration should later recieve a copy of this configuration to perform any additional steps required.

Required Methods

fn to_comp(&self) -> Composition

Creates a Composition from this configuration

fn to_instance(&self) -> TestInstance

Creates a new TestInstance and automatically adds the Composition from this configuration to it.

Implementors