Struct vaultrs_test::docker::TestInstance [−][src]
pub struct TestInstance {
pub instance: DockerTest,
}Expand description
A single test instance made up of several Compositions which are brought up for executing tests.
Use the run method to run the containers and perform the test logic.
Fields
instance: DockerTestImplementations
Returns a new TestInstance configured with the given Compositions.
Adds a Composition to this TestInstance.
Runs all containers from the associated Compositions, verifying they are running according to their startup conditions, and then calls the passed closure with runtime details.
This is the main method for running the TestInstance. All test logic should be encompassed within the passed closure. Creating and destroying containers happens upon entering/leaving the closure.