Trait vaultrs_test::docker::Server[][src]

pub trait Server {
    type Config;
    fn new(ops: &DockerOperations, config: &Self::Config) -> Self;
}
An instance of a server that is created after it’s associated Composition has been brought up.

This trait is the main vehicle for tests to interact with the running container. It should encompass all logic necessary for tests to successfully interact with it.

Associated Types

Required methods

Implementors